@@ -19,11 +19,6 @@ class DS18S20(Thermometer):
         (Default value = False)
         If True forces owserver to query the 1wire bus on each property access.
     """
-    def __repr__(self):
-        super_repr = super().__repr__().replace(')>', ',')
-        return (f'{super_repr} temphigh={self.temphigh}, '
-                f'templow={self.templow})>')
-
     @property
     def temphigh(self) -> int:
         """
